``pyramid_nacl_session``: Encrypting Pyramid Session Cookies
============================================================

.. image:: https://travis-ci.org/Pylons/pyramid_nacl_session.png?branch=master
        :target: https://travis-ci.org/Pylons/pyramid_nacl_session

.. image:: https://readthedocs.org/projects/pyramid_nacl_session/badge/?version=latest
        :target: http://docs.pylonsproject.org/projects/pyramid-nacl-session/en/latest/
        :alt: Documentation Status

This Pyramid add-on defines an encrypting, pickle-based cookie serializer,
using ``PyNaCl`` [1] to generate the symmetric encryption for the cookie state.


[1] http://pynacl.readthedocs.org/en/latest/secret/

See:  ``docs/index.rst`` for the documentation.

.. note::

   Initial development of this library was sponsored by ZeOmega Inc.
